@@ -1,5 +1,6 @@
 package Config::GitLike;
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(Bool HashRef ArrayRef Maybe Str);
 
 use File::Spec;
 use Cwd;
@@ -7,13 +8,13 @@ use Scalar::Util qw(openhandle);
 use Fcntl qw(O_CREAT O_EXCL O_WRONLY);
 use 5.008;
 
-our $VERSION = '1.10';
+our $VERSION = '1.12';
 
 
 has 'confname' => (
     is => 'rw',
     required => 1,
-    isa => 'Str',
+    isa => Str,
 );
 
 # not defaulting to {} allows the predicate is_loaded
@@ -21,32 +22,32 @@ has 'confname' => (
 has 'data' => (
     is => 'rw',
     predicate => 'is_loaded',
-    isa => 'HashRef',
+    isa => HashRef,
 );
 
 # key => bool
 has 'multiple' => (
     is => 'rw',
-    isa => 'HashRef',
+    isa => HashRef,
     default => sub { +{} },
 );
 
 has 'casing' => (
     is => 'rw',
-    isa => 'HashRef',
+    isa => HashRef,
     default => sub { +{} },
 );
 
 # filename where the definition of each key was loaded from
 has 'origins' => (
     is => 'rw',
-    isa => 'HashRef',
+    isa => HashRef,
     default => sub { +{} },
 );
 
 has 'config_files' => (
     is => 'rw',
-    isa => 'ArrayRef',
+    isa => ArrayRef,
     default => sub { [] },
 );
 
@@ -54,19 +55,19 @@ has 'config_files' => (
 # of only-write-things-that-git-config-can-read if you want to
 has 'compatible' => (
     is => 'rw',
-    isa => 'Bool',
-    default => 0,
+    isa => Bool,
+    default => sub { 0 },
 );
 
 has 'cascade' => (
     is => 'rw',
-    isa => 'Bool',
-    default => 0,
+    isa => Bool,
+    default => sub { 0 },
 );
 
 has 'encoding' => (
     is => 'rw',
-    isa => 'Maybe[Str]',
+    isa => Maybe[Str],
 );
 
 sub set_multiple {
@@ -1319,7 +1320,7 @@ written by git. The converse is usually true, but only if you don't take
 advantage of this module's increased permissiveness when it comes to key
 names. (See L<DIFFERENCES FROM GIT-CONFIG> for details.)
 
-This is an object-oriented module using L<Any::Moose|Any::Moose>. All
+This is an object-oriented module using L<Moo|Moo>. All
 subroutines are object method calls.
 
 A few methods have parameters that are always used for the same purpose:
